<?php
/**
 * Plugin Name:           GamiPress - WPAdverts integration
 * Plugin URI:            https://wordpress.org/plugins/gamipress-wpadverts-integration/
 * Description:           Connect GamiPress with WPAdverts.
 * Version:               1.0.0
 * Author:                GamiPress
 * Author URI:            https://gamipress.com/
 * Text Domain:           gamipress-wpadverts-integration
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.2
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               GamiPress\WPAdverts
 * @author                GamiPress
 * @copyright             Copyright (c) GamiPress
 */

final class GamiPress_WPAdverts {

    /**
     * @var         GamiPress_WPAdverts $instance The one true GamiPress_WPAdverts
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      GamiPress_WPAdverts self::$instance The one true GamiPress_WPAdverts
     */
    public static function instance() {

        if( !self::$instance ) {
            self::$instance = new GamiPress_WPAdverts();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'GAMIPRESS_WPADVERTS_VER', '1.0.0' );

        // Plugin path
        define( 'GAMIPRESS_WPADVERTS_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'GAMIPRESS_WPADVERTS_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            require_once GAMIPRESS_WPADVERTS_DIR . 'includes/admin.php';
            require_once GAMIPRESS_WPADVERTS_DIR . 'includes/listeners.php';
            require_once GAMIPRESS_WPADVERTS_DIR . 'includes/triggers.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {
        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'GAMIPRESS_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'GamiPress - WPAdverts integration requires %s and %s in order to work. Please install and activate them.', 'gamipress-wpadverts-integration' ),
                        '<a href="https://wordpress.org/plugins/gamipress/" target="_blank">GamiPress</a>',
                        '<a href="https://wordpress.org/plugins/wpadverts/" target="_blank">WPAdverts</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'GAMIPRESS_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'GamiPress' ) ) {
            return false;
        }

        // Requirements on multisite install
        if( is_multisite() && gamipress_is_network_wide_active() && is_main_site() ) {

            // On main site, need to check if integrated plugin is installed on any sub site to load all configuration files
            if( gamipress_is_plugin_active_on_network( 'wpadverts/wpadverts.php' ) ) {
                return true;
            }

        }

        if ( ! function_exists( 'adverts_init' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = GAMIPRESS_WPADVERTS_DIR . '/languages/';
        $lang_dir = apply_filters( 'gamipress_wpadverts_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gamipress-wpadverts-integration' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'gamipress-wpadverts-integration', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/gamipress-wpadverts-integration/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/gamipress-wpadverts-integration/ folder
            load_textdomain( 'gamipress-wpadverts-integration', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/gamipress-wpadverts-integration/languages/ folder
            load_textdomain( 'gamipress-wpadverts-integration', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'gamipress-wpadverts-integration', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true GamiPress_WPAdverts instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \GamiPress_WPAdverts The one true GamiPress_WPAdverts
 */
function GamiPress_WPAdverts() {
    return GamiPress_WPAdverts::instance();
}
add_action( 'plugins_loaded', 'GamiPress_WPAdverts' );
